viswaternet.utils package
=========================

Submodules
----------

viswaternet.utils.convert\_excel module
---------------------------------------

.. automodule:: viswaternet.utils.convert_excel
   :members:
   :undoc-members:
   :show-inheritance:

viswaternet.utils.normalize\_parameter module
---------------------------------------------

.. automodule:: viswaternet.utils.normalize_parameter
   :members:
   :undoc-members:
   :show-inheritance:

viswaternet.utils.save\_fig module
----------------------------------

.. automodule:: viswaternet.utils.save_fig
   :members:
   :undoc-members:
   :show-inheritance:

viswaternet.utils.unit\_conversion module
-----------------------------------------

.. automodule:: viswaternet.utils.unit_conversion
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: viswaternet.utils
   :members:
   :undoc-members:
   :show-inheritance:
